@@ -964,7 +964,7 @@ relational knowledge is contained in the default context GLOBAL.")
     (cond ((eq '$zero sgn) t)
 	  ((memq sgn '($pos $neg $pn)) nil)
 
-	  ((and (memq sgn '($complex $imaginary)) (linearp z '$%i))
+	  ((memq sgn '($complex $imaginary)) ;; previously checked also for (linearp z '$%i))
 	   (setq rsgn ($csign ($realpart z)))
 	   (setq isgn ($csign ($imagpart z)))
 	   (cond ((and (eq '$zero rsgn) (eq '$zero isgn)) t)
@@ -1194,10 +1194,11 @@ relational knowledge is contained in the default context GLOBAL.")
 
 (defun numer (x)
   (let (($numer t) ; currently, no effect on $float, but proposed to
+        ($ratprint nil)
         result)
-      ;; Catch a Lisp error, if a floating point overflow occurs.
-      (setq result (let ((errset nil)) (errset ($float x))))
-      (if result (car result) nil)))
+    ;; Catch a Lisp error, if a floating point overflow occurs.
+    (setq result (let ((errset nil)) (errset ($float x))))
+    (if result (car result) nil)))
 
 (defun constp (x)
   (cond ((floatp x) 'float)
@@ -1217,37 +1218,53 @@ relational knowledge is contained in the default context GLOBAL.")
 		    (if (eq ans 'numer) (setq ans 'symbol)))
 		   (t (return nil)))))))
 
+(mapcar #'(lambda (s) (putprop (first s) (second s) 'sign-function))
+	(list
+	 (list 'mtimes 'sign-mtimes)
+	 (list 'mplus 'sign-mplus)
+	 (list 'mexpt 'sign-mexpt)
+	 (list '%log 'sign-log)
+	 (list 'mabs 'sign-mabs)
+	 (list '$min #'(lambda (x) (sign-minmax (caar x) (cdr x))))
+	 (list '$max #'(lambda (x) (sign-minmax (caar x) (cdr x))))
+	 (list '%csc #'(lambda (x) (sign (inv* (cons (ncons (zl-get (caar x) 'recip)) (cdr x))))))
+	 (list '%csch #'(lambda (x) (sign (inv* (cons (ncons (zl-get (caar x) 'recip)) (cdr x))))))
+
+	 (list '%signum #'(lambda (x) (sign (cadr x))))
+	 (list '%erf #'(lambda (x) (sign (cadr x))))
+	 (list '$li #'(lambda (x) 
+			(let ((z (first (margs x))) (n (cadadr x)))
+			  (if (and (mnump n) (eq t (mgrp z 0)) (eq t (mgrp 1 z))) (sign z) (sign-any x)))))))
 (defmfun sign (x)
   (cond ((mnump x) (setq sign (rgrp x 0) minus nil odds nil evens nil))
-	((and *complexsign* (atom x) (eq x '$%i))
+	((and *complexsign* (symbolp x) (eq x '$%i))
 	 ;; In Complex Mode the sign of %i is $imaginary.
 	 (setq sign '$imaginary))
-	((atom x) (if (eq x '$%i) (imag-err x)) (sign-any x))
-	((eq (caar x) 'mtimes) (sign-mtimes x))
-	((eq (caar x) 'mplus) (sign-mplus x))
-	((eq (caar x) 'mexpt) (sign-mexpt x))
-        ((eq (caar x) '%log) (sign-log x))
-	((eq (caar x) 'mabs) (sign-mabs x))
-	((member (caar x) '($min $max) :test #'eq) (sign-minmax (caar x) (cdr x)))
-	((member (caar x) '(%csc %csch) :test #'eq)
-	 (sign (inv* (cons (ncons (zl-get (caar x) 'recip)) (cdr x)))))
+	((symbolp x) (if (eq x '$%i) (imag-err x)) (sign-any x))
+	((and (consp x) (symbolp (caar x)) (not (specrepp x)) (get (caar x) 'sign-function))
+	 (funcall (get (caar x) 'sign-function) x))
+	((and (consp x) (not (specrepp x)) ($subvarp (mop x)) (get (mop (mop x)) 'sign-function))
+	 (funcall (get (mop (mop x)) 'sign-function) x))
 	((specrepp x) (sign (specdisrep x)))
 	((kindp (caar x) '$posfun) (sign-posfun x))
-	((or (member (caar x) '(%signum %erf) :test #'eq)
-	     (and (kindp (caar x) '$oddfun) (kindp (caar x) '$increasing)))
-	 (sign-oddinc x))
+	((and (kindp (caar x) '$oddfun) (kindp (caar x) '$increasing)) (sign-oddinc x))
 	(t (sign-any x))))
 
 (defun sign-any (x)
   (cond ((and *complexsign*
-	      (or (and (atom x) (decl-complexp x))
-		  (and (not (atom x)) (decl-complexp (caar x)))))
-	 ;; In Complex Mode look for symbols declared to be complex.
-	 (when *debug-compar*
-	   (format t "~&SIGN-ANY with ~A~&   Symbol declared to be complex found.~%" x))
-	 (if (and (atom x) ($featurep x '$imaginary))
-	     (setq sign '$imaginary)
-	     (setq sign '$complex)))
+              (symbolp x)
+              (decl-complexp x))
+         ;; In Complex Mode look for symbols declared to be complex.
+         (if ($featurep x '$imaginary)
+             (setq sign '$imaginary)
+             (setq sign '$complex)))
+        ((and *complexsign*
+              (not (atom x))
+              (decl-complexp (caar x)))
+         ;; A function f(x), where f is declared to be imaginary or complex.
+         (if ($featurep (caar x) '$imaginary)
+             (setq sign '$imaginary)
+             (setq sign '$complex)))
 	(t
 	 (dcompare x 0)
 	 (if (and $assume_pos
@@ -1328,7 +1345,7 @@ relational knowledge is contained in the default context GLOBAL.")
 (defun signdiff-special (xlhs xrhs)
   ;; xlhs may be a constant
   (let ((sgn nil))
-    (when (or (and (numberp xrhs) (minusp xrhs)
+    (when (or (and (realp xrhs) (minusp xrhs)
 		   (not (atom xlhs)) (eq (sign* xlhs) '$pos))
 					; e.g. sign(a^3+%pi-1) where a>0
 	      (and (mexptp xlhs)
@@ -1367,7 +1384,70 @@ relational knowledge is contained in the default context GLOBAL.")
     (when sgn (setq sign sgn minus nil odds nil evens nil)
 	  t)))
 
+;;; Look for symbols with an assumption a > n or a < -n, where n is a number.
+;;; For this case shift the symbol a -> a+n in a summation and multiplication.
+;;; This handles cases like a>1 and b>1 gives sign(a+b-2) -> pos.
+
+(defun sign-shift (expr)
+  (do ((l (cdr expr) (cdr l))
+       (fl nil)
+       (acc nil))
+      ((null l) (addn acc nil))
+    (cond ((symbolp (car l))
+           ;; Get the facts related to the symbol (car l)
+           ;; Reverse the order to test the newest facts first.
+           (setq fl (reverse (cdr (facts1 (car l)))))
+           (push (car l) acc)
+           (dolist (f fl)
+             (cond ((and (eq (caar f) 'mgreaterp)
+                         (mnump (caddr f))
+                         (eq ($sign (caddr f)) '$pos))
+                    ;; The case a > n, where a is a symbol and n a number.
+                    ;; Add the number to the list of terms.
+                    (return (push (caddr f) acc)))
+                   ((and (eq (caar f) 'mgreaterp)
+                         (mnump (cadr f))
+                         (eq ($sign (cadr f)) '$neg))
+                    ;; The case a < -n, where a is a symbol and n a number.
+                    ;; Add the number to the list of terms.
+                    (return (push (cadr f) acc))))))
+          ((mtimesp (car l))
+           (let ((acctimes) (flag))
+             ;; Go through the factors of the multiplication.
+             (dolist (ll (cdar l))
+               (cond ((symbolp ll)
+                      ;; Get the facts related to the symbol (car l)
+                      ;; Reverse the order to test the newest facts first.
+                      (setq fl (reverse (cdr (facts1 ll))))
+                      (dolist (f fl)
+                        (cond ((and (eq (caar f) 'mgreaterp)
+                                    (mnump (caddr f))
+                                    (eq ($sign (caddr f)) '$pos))
+                               ;; The case a > n, where a is a symbol and n a
+                               ;; number. Add the number to the list of terms.
+                               (setq flag t)
+                               (return (push (add ll (caddr f)) acctimes)))
+                              ((and (eq (caar f) 'mgreaterp)
+                                    (mnump (cadr f))
+                                    (eq ($sign (cadr f)) '$neg))
+                               ;; The case a < -n, where a is a symbol and n a
+                               ;; number. Add the number to the list of terms.
+                               (setq flag t)
+                               (return (push (add ll (cadr f)) acctimes)))))
+                        (when (not flag) (push ll acctimes)))
+                     (t
+                      (push ll acctimes))))
+             (if flag
+                 ;; If a shift has been done expand the factors.
+                 (push ($multthru (muln acctimes nil)) acc)
+                 (push (muln acctimes nil) acc))))
+          (t
+           (push (car l) acc)))))
+
 (defun signsum (x)
+  (setq x (sign-shift x))
+  ;; x might be simplified to an atom in sign-shift.
+  (when (atom x) (setq x (cons '(mplus) (list x))))
   (do ((l (cdr x) (cdr l)) (s '$zero))
       ((null l) (setq sign s minus nil odds (list x) evens nil)
        (cond (*complexsign*
@@ -1493,7 +1573,7 @@ relational knowledge is contained in the default context GLOBAL.")
 				 (complexsign
 				  ;; The only place the variable complexsign
 				  ;; is used. Unfortunately, one routine in
-				  ;; topoly.lisp in /share/contrib depends on
+				  ;; to_poly.lisp in /share/to_poly_solve depends on
 				  ;; this piece of code. Perhaps we can remove
 				  ;; the dependency. (12/2008)
 				  (setq sign-base (setq sign-expt '$pnz)))
@@ -1522,25 +1602,19 @@ relational knowledge is contained in the default context GLOBAL.")
 ;;; Determine the sign of log(expr). This function changes the special variable sign.
 
 (defun sign-log (x)
-  (setq x (cadr x)) ;; looking at sign of log(x)
-  (cond ((eq t (meqp x 1)) (setf sign '$zero)) ;; log(1) = 0.
-	;; for x on the unit circle and x # 1, log(x) is pure imaginary
-	((and  *complexsign* (eq t (meqp 1 (take '(mabs) x))) (eq t (mnqp x 1)))
-	 (setf sign '$imaginary))
-	;; log(x) is positive for x > 1
-	((eq t (mgrp x 1)) (setf sign '$pos))
-	((eq t (mgqp x 1)) (setf sign '$pz))
-	;; log(x) is negative for 0 < x < 1.
-	((and (eq t (mgrp x 0)) (eq t (mgrp 1 x))) (setf sign '$neg))
-
-	;; log(x) is real for x > 0
-	((eq t (mgrp x 0)) (setf sign '$pnz))
-
-	;; Nothing is known.  Return $complex if allowed, 
-	;;  otherwise pnz
-	(*complexsign* (setf sign '$complex)) 
-	(t (setf sign '$pnz)))
-  sign)
+  (setq x (cadr x))
+  (setq sign
+	(cond ((eq t (mgrp x 0))
+	       (cond ((eq t (mgrp 1 x)) '$neg)
+		     ((eq t (meqp x 1)) '$zero);; log(1) = 0.
+		     ((eq t (mgqp 1 x)) '$nz)
+		     ((eq t (mgrp x 1)) '$pos)
+		     ((eq t (mgqp x 1)) '$pz)
+		     ((eq t (mnqp x 1)) '$pn)
+		     (t '$pnz)))
+	      ((and  *complexsign* (eql 1 (cabs x))) '$imaginary)
+	      (*complexsign* '$complex)
+	      (t '$pnz))))
 
 (defun sign-mabs (x)
   (sign (cadr x))
@@ -1685,7 +1759,7 @@ relational knowledge is contained in the default context GLOBAL.")
           ind))
         ;; Properties not related to the assume database.
         ((and (member ind opers) (get e ind)))
-        ((and (member ind '($evfun $evflag $bindtest $special $nonarray))
+        ((and (member ind '($evfun $evflag $bindtest $nonarray))
               (get e (stripdollar ind))))
         ((and (eq ind '$noun)
               (get e (stripdollar ind))
@@ -1859,9 +1933,6 @@ relational knowledge is contained in the default context GLOBAL.")
 (defun intp (l)
   (every #'maxima-integerp (cdr l)))
 
-(defun intp-mexpt (e)
-  (and (integerp (caddr e)) (not (minusp (caddr e))) (maxima-integerp (cadr e))))
-
 (defmfun mevenp (e)
   (cond ((integerp e) (not (oddp e)))
 	((mnump e) nil)
@@ -2317,6 +2388,12 @@ relational knowledge is contained in the default context GLOBAL.")
 	  (kind %coth $oddfun)
 	  (kind %csch $oddfun)
 	  (kind %sech $posfun)
+	  (kind %asinh $increasing) (kind %asinh $oddfun)
+	  ;; It would be nice to say %acosh is $posfun, but then
+	  ;; assume(xn<0); abs(acosh(xn)) -> acosh(xn), which is wrong
+	  ;; since acosh(xn) is complex.
+	  (kind %acosh $increasing)
+	  (kind %atanh $increasing) (kind %atanh $oddfun)
 	  (kind $li $complex)
 	  (kind $lambert_w $complex)
 	  (kind %cabs $complex)))
