@@ -47,15 +47,12 @@
 (defmvar mplc* nil)
 (defmvar mm* 1)
 (defmvar alpha nil)
-(defmvar smallprimes '(3 5 7 11. 13. 17. 19. 23. 29. 31. 37. 41. 43. 47. 53. 59. 61.))
+;(defmvar smallprimes '(3 5 7 11. 13. 17. 19. 23. 29. 31. 37. 41. 43. 47. 53. 59. 61.))
 
 ;; External specials
 
 (defmvar $nalgfac t "If t use bmt's algebraic factoring algorithm")
 
-(defun csqfrp ($factorflag)
-  (null (delete 1 (oddelm (cdr (cfactor $factorflag))))))
-
 (defun primcyclo (n)
   (let ((*g* (gensym "PRIMCYCLO-"))
 	(nl (loop for (c e) on (cfactorw n) by #'cddr
@@ -659,31 +656,32 @@
 				      (degvector nil 1 (car subval)))))))
      (setq subval nil)
      (setq p poly)
-     (cond ((null val1)
-	    (setq subvar1 ovarlist)
-	    (setq subval1 (polysubst (nzeros (length subvar1) nil) subvar1))
-	    (go tag)))
+     (when (null val1)
+       (setq subvar1 ovarlist)
+       (setq subval1 (polysubst (make-list (length subvar1) :initial-element 0) subvar1))
+       (go tag))
      (fixvl val1 ovarlist)
      (fixvl1 val1 ovarlist)
-     (cond (subval1 (setq subval1 (polysubst subval1 subvar1))))
+     (when subval1 (setq subval1 (polysubst subval1 subvar1)))
      (setq subval (polysubst (completevector nil 0 (length subval) 1) subvar))
      tag  (fixvl subval1 subvar1)
      (setq subval1 nil subvar1 nil)
      (fixvl0 subvar subval (reverse ovarlist))
-     (cond (algfac* (setq genvar (cons (car alpha) genvar))))
+     (when algfac* (push (car alpha) genvar))
      (setq poly (cpber3 poly p))
      (setq genvar origenvar)
      (return poly)))
 
 (defun polysubst (a b)
-  ;;  (declare (special p))
   (prog (lc *inl3 d n modulus)
-     (cond (modulu* (setq modulus modulu*)))
+     (when modulu* (setq modulus modulu*))
      (setq *inl3 t lc (caddr p) n (length a))
      loop (setq d (pcsubsty a b lc))
-     (cond ((equal 0 d) (go inl)))
-     ((lambda (modulus) (setq d (pcsubsty a b p))) nil)
-     (cond ((sqfrp (pmod d) (car d)) (setq p d) (return a)))
+     (when (equal 0 d) (go inl))
+     (let ((modulus nil))
+       (setq d (pcsubsty a b p)))
+     (when (sqfrp (pmod d) (car d))
+       (setq p d) (return a))
      inl  (setq a (increaselist a n))
      (go loop)))
 
@@ -749,7 +747,7 @@
   (cond (*inl3 l)
 	(t (cond ((equal elm 2)
 		  (cond (modulu*
-			 (merror "Not enough choices for substitution."))
+			 (merror (intl:gettext "factor: not enough choices for substitution.")))
 			(t (rand n 13.))))
 		 ((equal ne n)
 		  (incf elm)
@@ -786,23 +784,21 @@
 		    (t (nconc factor
 			      (nprod lc
 				     v
-				     (cons ((lambda (modulus)
-					      (ptimes olc
-						      (cadr olfact)))
-					    plim)
+				     (cons (let ((modulus plim))
+					     (ptimes olc (cadr olfact)))
 					   (cddr olfact)))))))
 	     (go out))
 	    ((and (null (cdr lp)) (or (null (cdr olfact)) (null (cddr olfact))))
 	     (setq ans (cons v factor))
 	     (go out)))
      (setq af (car lp))
-     (cond ((setq qnt ((lambda (modulus) (testdivide v af)) modulu*))
+     (cond ((setq qnt (let ((modulus modulu*))
+			(testdivide v af)))
 	    (setq factor (cons af factor))
 	    (setq lc (ptimes lc (caddr af)))
 	    (setq v qnt)
-	    ((lambda (modulus)
-	       (setq olc (ptimes (caddr (cadr lfunct)) olc)))
-	     plim)
+	    (let ((modulus plim))
+	      (setq olc (ptimes (caddr (cadr lfunct)) olc)))
 	    (rplacd lfunct (cddr lfunct)))
 	   (t (setq lfunct (cdr lfunct))))
      (setq lp (cdr lp))
@@ -817,15 +813,10 @@
      (setq d (+ (car p) (multideg (cadr p))) p (cddr p) m (max d m))
      (go loop)))
 
-(defun oddelm (l)
-  (prog (ans)
-   loop (cond ((null l) (return (nreverse ans)))
-	      ((null (cdr l)) (return (nreverse (cons (car l) ans)))))
-   (setq ans (cons (car l) ans) l (cddr l))
-   (go loop)))
-
-
-
+(defun oddelm (list)
+  "return a list of the first. third etc. elements of list"
+  (loop for el in list by #'cddr
+        collect el))
 
 (defun cpber3 (v u)
   (prog (factz alcinv lc plim monic* sharpcont limk var vfact)
@@ -1036,7 +1027,8 @@
      (setq limk (klim poly modulus))
      (setq factz (zfact poly factp limk nil)factp nil)
      (setq poly (trufac poly
-			((lambda (modulus) (restorelc factz lc)) plim)
+			(let ((modulus plim))
+			  (restorelc factz lc))
 			(nreverse factz)
 			nil
 			nil))
@@ -1289,7 +1281,7 @@
 	 (deg  (cadr v)) (algcont 0))
      (declare (special ncont lmin nf deg algcont))
      (setq nf (integer-length deg))
-     (setq lchar1 (if gauss '(3 7 11. 19. 23. 29. 31. 37.) smallprimes))
+     (setq lchar1 (if gauss '(3 7 11. 19. 23. 29. 31. 37.) (cdr *small-primes*)))
      test (setq modulus (car lchar1))
      (setq u (pmod v))
      (cond ((or (zerop (rem sharpcont modulus))
@@ -1315,11 +1307,11 @@
      nextp (setq lchar1 (cdr lchar1))
      (cond ((null lchar1)
 	    (cond ((not (zerop lmin)) (go out))
-		  (t (merror "Factor ran out of primes."))))
+		  (t (merror (intl:gettext "factor: ran out of primes.")))))
 	   ((and algfac* minpoly* (> algcont 6))
 	    (cond ((ziredup minpoly*)(setq trl* tr)(setq modulus nil)
 		   (return 'splitcase))
-		  (t (merror "The minimal poly must be irreducible over the integers.")))))
+		  (t (merror (intl:gettext "factor: the minimal polynomial must be irreducible over the integers."))))))
      (go test)
      out  (setq modulus bmod trl* tr)
      (return b)))
