@@ -246,171 +246,6 @@ When one changes, the other does too."
 				(setq *maxima-lang-subdir* (concatenate 'string *maxima-lang-subdir* ".koi8r")))))
 			(t  (setq *maxima-lang-subdir* nil))))))))
 
-;; Return a list of all the subdirectories of the sharedir.  If
-;; sharedir has directories /foo/share/affine and
-;; /foo/share/contrib/bitwise, the we want to return the list
-;; ("affine" "contrib/bitwise").
-#+cmu
-(defun share-subdirs-list ()
-  (let* ((share-root (pathname (concatenate 'string *maxima-sharedir* "/")))
-	 (file-list (directory (merge-pathnames (make-pathname :directory '(:relative :wild-inferiors)
-							       :name :wild :type :wild)
-						share-root)
-			       :truenamep nil)))
-    ;; Remove stuff we don't want like files and CVS directories.
-    ;; Anything else?
-    (setf file-list (remove-if #'(lambda (x)
-				   (or
-				    ;; Remove files (pathnames that have a name or type)
-				    (or (pathname-name x)
-					(pathname-type x))
-				    ;; Remove CVS directories
-				    (equal "CVS" (car (last (pathname-directory x))))
-				    ))
-			       file-list))
-    ;; Now just want the part after the *maxima-sharedir*, and we want
-    ;; strings.  
-    (mapcar #'(lambda (x)
-		(let ((dir (make-pathname :directory (butlast (pathname-directory x))
-					  :name (car (last (pathname-directory x))))))
-		  (enough-namestring dir share-root)))
-	    file-list)))
-
-#+clisp
-(defun share-subdirs-list ()
-  ;; This doesn't work yet on windows.  Give up in that case and use
-  ;; the default list.
-  (if (string= *autoconf-win32* "true")
-      (default-share-subdirs-list)
-      (let* ((share-root (pathname (concatenate 'string *maxima-sharedir* "/")))
-	     (dir-list (directory (merge-pathnames (make-pathname :directory '(:relative :wild-inferiors))
-						   share-root))))
-	;; dir-list contains all of the directories.  Remove stuff we
-	;; don't want like CVS directories.  Anything else?
-	(setf dir-list (delete-if #'(lambda (x)
-				      ;; Remove CVS directories
-				      (or (equal x share-root)
-					  (equal "CVS" (car (last (pathname-directory x))))))
-				  dir-list))
-	;; Now just want the part after the *maxima-sharedir*, and we want
-	;; strings.
-	(setf dir-list
-	      (mapcar #'(lambda (x)
-			  (let ((dir (make-pathname :directory (butlast (pathname-directory x))
-						    :name (car (last (pathname-directory x))))))
-			    (enough-namestring dir share-root)))
-		      dir-list))
-	;; Sort in alphabetical order
-	(sort dir-list #'string-lessp))))
-
-#+(or ecl sbcl)
-(defun share-subdirs-list ()
-  ;; This doesn't work yet on windows.  Give up in that case and use
-  ;; the default list.
-  (if (string= *autoconf-win32* "true")
-      (default-share-subdirs-list)
-      ;; The call to DIRECTORY is to get ecl to follow any symlinks so
-      ;; that the subsequent call to directory all start with the same
-      ;; initial path.
-      (let* ((share-root (first (directory (pathname (concatenate 'string *maxima-sharedir* "/")))))
-	     (dir-list (directory (merge-pathnames (make-pathname :directory '(:relative :wild-inferiors))
-						   share-root))))
-	;; dir-list contains all of the directories.  Remove stuff we
-	;; don't want like CVS directories.  Anything else?
-	(setf dir-list (delete-if #'(lambda (x)
-				      ;; Remove CVS directories
-				      (or (equal x share-root)
-					  (equal "CVS" (car (last (pathname-directory x))))))
-				  dir-list))
-	;; Now just want the part after the *maxima-sharedir*, and we want
-	;; strings.
-	(setf dir-list
-	      (mapcar #'(lambda (x)
-			  (let ((dir (make-pathname :directory (butlast (pathname-directory x))
-						    :name (car (last (pathname-directory x))))))
-			    (enough-namestring dir share-root)))
-		      dir-list))
-	;; Sort in alphabetical order
-	(sort dir-list #'string-lessp))))
-
-
-(defun default-share-subdirs-list ()
-  ;; Default implementation.  Eventually this should go away.
-  '("affine"
-    "algebra"
-    "algebra/charsets"
-    "algebra/solver"
-    "calculus"
-    "combinatorics"
-    "contrib"
-    "contrib/amatrix"
-    "contrib/bitwise"
-    "contrib/boolsimp"
-    "contrib/descriptive"
-    "contrib/diffequations"
-    "contrib/diffequations/tests"
-    "contrib/distrib"
-    "contrib/ezunits"
-    "contrib/finance"
-    "contrib/format"
-    "contrib/fourier_elim"
-    "contrib/fractals"
-    "contrib/fresnel"
-    "contrib/gentran"
-    "contrib/gentran/test"
-    "contrib/gf"
-    "contrib/graphs"
-    "contrib/Grobner"
-    "contrib/integration"
-    "contrib/levin"
-    "contrib/lurkmathml"
-    "contrib/maximaMathML"
-    "contrib/mcclim"
-    "contrib/namespaces"
-    "contrib/noninteractive"
-    "contrib/numericalio"
-    "contrib/pdiff"
-    "contrib/prim"
-    "contrib/rand"
-    "contrib/sarag"
-    "contrib/simplex"
-    "contrib/simplex/Tests"
-    "contrib/solve_rec"
-    "contrib/state"
-    "contrib/stats"
-    "contrib/stringproc"
-    "contrib/vector3d"
-    "contrib/unit"
-    "contrib/Zeilberger"
-    "diff_form"
-    "diffequations"
-    "dynamics"
-    "draw"
-    "lapack"
-    "lbfgs"
-    "linearalgebra"
-    "integequations"
-    "integration"
-    "macro"
-    "matrix"
-    "minpack"
-    "misc"
-    "numeric"
-    "orthopoly"
-    "hypergeometric"
-    "physics"
-    "simplification"
-    "sym"
-    "tensor"
-    "tensor/tests"
-    "trigonometry"
-    "utils"
-    "vector"))
-
-#-(or cmu clisp ecl sbcl)
-(defun share-subdirs-list ()
-  (default-share-subdirs-list))
-
 (defun set-pathnames ()
   (let ((maxima-prefix-env (maxima-getenv "MAXIMA_PREFIX"))
 	(maxima-layout-autotools-env (maxima-getenv "MAXIMA_LAYOUT_AUTOTOOLS"))
@@ -476,10 +311,10 @@ When one changes, the other does too."
 	      #+ecl "fas"
 	      #-(or gcl cmu scl sbcl clisp allegro openmcl lispworks ecl)
 	      "")
-	 (lisp-patterns (concatenate 'string "###.{" ext ",lisp,lsp}"))
-	 (maxima-patterns "###.{mac,mc}")
-	 (demo-patterns "###.{dem,dm1,dm2,dm3,dmt}")
-	 (usage-patterns "##.{usg,texi}")
+	 (lisp-patterns (concatenate 'string "$$$.{" ext ",lisp,lsp}"))
+	 (maxima-patterns "$$$.{mac,mc}")
+	 (demo-patterns "$$$.{dem,dm1,dm2,dm3,dmt}")
+	 (usage-patterns "$$.{usg,texi}")
 	 (share-subdirs-list (share-subdirs-list))
 	 ;; Smash the list of share subdirs into a string of the form
 	 ;; "{affine,algebra,...,vector}" .
@@ -713,7 +548,17 @@ When one changes, the other does too."
   (in-package :maxima)
   (setf *load-verbose* nil)
   (setf *debugger-hook* #'maxima-lisp-debugger)
-  (setf *print-circle* t) ;; "assume" db contains circular objects
+  ;; See discussion on the maxima list
+  ;; http://www.math.utexas.edu/pipermail/maxima/2011/024014.html.
+  ;; Set *print-length* and *print-level* to some reasonable values so
+  ;; that normal Lisp structure is shown, but prevent typical circular
+  ;; structures from hanging Lisp.
+  ;;
+  ;; (We do we set these instead of binding them?)
+  (setf *print-circle* nil)
+  (setf *print-length* 100)
+  (setf *print-level* 15)
+  
   ;; GCL: print special floats, which are generated whether or not this flag is enabled
   #+gcl (setf si:*print-nans* t)
   #+ccl
