@@ -15,10 +15,10 @@
 ;; This is the Match Compiler.
 
 (declare-top (special *expr *rules *rulelist $rules alist $props 
-		      *afterflag args boundlist *a* pt
+		      args boundlist *a* pt
 		      reflist topreflist program $noundisp))
 
-(setq *afterflag nil)
+(defvar *afterflag nil)
 
 (defmvar $announce_rules_firing nil)
 
@@ -28,7 +28,7 @@
 
 (defun proc-$matchdeclare (x)
   (if (oddp (length x))
-      (merror "`matchdeclare' takes an even number of arguments."))
+      (merror (intl:gettext "matchdeclare: must be an even number of arguments.")))
   (do ((x x (cddr x))) ((null x))
     (cond ((symbolp (car x))
 	   (cond ((and (not (symbolp (cadr x)))
@@ -80,8 +80,10 @@
   (prog (topreflist program prog-variables) 
      (setq topreflist (list e))
      (cond ((atom (errset (compilematch e pt)))
-	    (merror "Match processing aborted~%"))
-	   (t (mtell "~M Will be matched uniquely since sub-parts would otherwise be ambigious.~%" pt)
+	    (merror (intl:gettext "defmatch: failed to compile match for pattern ~M") pt))
+	   (t
+         ;; NOTE TO TRANSLATORS: MEANING OF FOLLOWING TEXT IS UNKNOWN
+         (mtell "defmatch: ~M will be matched uniquely since sub-parts would otherwise be ambigious.~%" pt)
 	      (return (list 'lambda
 			    (list e)
 			    `(declare (special ,e))
@@ -112,7 +114,8 @@
 		      (setq leftover (delete (car f) leftover :test #'equal))
 		      (go a1))
 		     (t
-		      (mtell "~M partitions `sum'" (cons '(mplus) leftover))
+		      ;; Almost nobody knows what this means. Just suppress the noise.
+		      ;; (mtell "COMPILEPLUS: ~M partitions '+' expression.~%" (cons '(mplus) leftover))
 		      (setq boundlist (append boundlist (atomson leftover)))
 		      (return (emit (list 'cond
 					  (list (list 'part+
@@ -199,7 +202,7 @@
 	       (genref)
 	       (list 'findfun e (memqargs (caaar p)) ''mplus)))
    (cond ((eq (caaar p) 'mplus)
-	  (mtell "~M~%Warning: + within +~%" (car p))
+	  (mtell (intl:gettext "COMPILEPLUS: warning: '+' within '+' in: ~M~%") (car p))
 	  (compileplus (car reflist) (car p)))
 	 (t (emit (list 'setq (genref) (list 'kdr (cadr reflist))))
 	    (compileeach (car reflist) (cdar p))))
@@ -228,7 +231,8 @@
 		      (setq leftover (delete (car f) leftover :test #'equal))
 		      (go a1))
 		     (t
-		      (mtell "~M partitions `product'" (cons '(mtimes) leftover))
+		      ;; Almost nobody knows what this means. Just suppress the noise.
+		      ;; (mtell "COMPILETIMES: ~M partitions '*' expression.~%" (cons '(mtimes) leftover))
 		      (setq boundlist (append boundlist (atomson leftover)))
 		      (return (emit (list 'cond
 					  (list (list 'part*
@@ -294,7 +298,7 @@
 	       (genref)
 	       (list 'findfun e (memqargs (caaar p)) ''mtimes)))
    (cond ((eq (caaar p) 'mtimes)
-	  (mtell "~M~%Warning: * within *" (car p))
+	  (mtell (intl:gettext "COMPILETIMES: warning: '*' within '*' in: ~M~%") (car p))
 	  (compiletimes (car reflist) (car p)))
 	 (t (emit (list 'setq (genref) (list 'kdr (cadr reflist))))
 	    (compileeach (car reflist) (cdar p))))
@@ -315,14 +319,14 @@
      (setq pt (copy-tree (setq pt* (simplify (cadr l)))))
      (cond ((atom pt)
 	    (setq pt (copy-tree (setq pt* (meval pt))))
-	    (mtell "~M~%Is the pattern~%" pt)))
+	    (mtell (intl:gettext "defmatch: evaluation of atomic pattern yields: ~M~%") pt)))
      (setq args (cddr l))
-     (cond ((null (allatoms args)) (mtell "Non-atomic pattern variables")
+     (cond ((null (allatoms args)) (mtell (intl:gettext "defmatch: some pattern variables are not atoms."))
 	    (return nil)))
      (setq boundlist args)
      (setq *a* (genref))
      (cond ((atom (errset (compilematch *a* pt)))
-	    (merror "Match processing aborted~%"))
+	    (merror (intl:gettext "defmatch: failed to compile match for pattern ~M") pt))
 	   (t (meta-fset name
 			 (list 'lambda
 			       (cons *a* args)
@@ -362,14 +366,15 @@
      (setq pt (copy-tree (simplifya (car l) nil)))
      (setq name pt) 
      (setq rhs (copy-tree (simplifya (cadr l) nil)))
-     (cond ((alike1 pt rhs) (merror "Circular rule attempted - `tellsimp'"))
-	   ((or (atom pt) (mget (setq name (caar pt)) 'matchdeclare))
-	    (merror "~%~A unsuitable~%" (fullstrip1 (getop name))))
+     (cond ((alike1 pt rhs) (merror (intl:gettext "tellsimp: circular rule attempted.")))
+	   ((atom pt) (merror (intl:gettext "tellsimp: pattern must not be an atom; found: ~A") (fullstrip1 (getop name))))
+	   ((mget (setq name (caar pt)) 'matchdeclare)
+	    (merror (intl:gettext "tellsimp: main operator of pattern must not be match variable; found: ~A") (fullstrip1 (getop name))))
 	   ((member name '(mplus mtimes) :test #'eq)
-	    (mtell "Warning: Putting rules on '+' or '*' is inefficient, and may not work.~%")))
+	    (mtell (intl:gettext "tellsimp: warning: putting rules on '+' or '*' is inefficient, and may not work.~%"))))
      (setq *a* (genref))
      (cond ((atom (errset (compileeach *a* (cdr pt))))
-	    (merror "Match processing aborted~%")))
+	    (merror (intl:gettext "tellsimp: failed to compile match for pattern ~M") (cdr pt))))
      (setq oldstuff (get name 'operators))
      (setq rulenum (mget name 'rulenum))
      (cond ((null rulenum) (setq rulenum 1.)))
@@ -456,14 +461,15 @@
      (setq pt (copy-tree (simplifya (car l) nil)))
      (setq name pt)
      (setq rhs (copy-tree (simplifya (cadr l) nil)))
-     (cond ((alike1 pt rhs) (merror "Circular rule attempted - `tellsimpafter'"))
-	   ((or (atom pt) (mget (setq name (caar pt)) 'matchdeclare))
-	    (merror "~%~A unsuitable~%" (fullstrip1 (getop name)))))
+     (cond ((alike1 pt rhs) (merror (intl:gettext "tellsimpafter: circular rule attempted.")))
+	   ((atom pt) (merror (intl:gettext "tellsimpafter: pattern must not be an atom; found: ~A") (fullstrip1 (getop name))))
+	   ((mget (setq name (caar pt)) 'matchdeclare)
+	    (merror (intl:gettext "tellsimpafter: main operator of pattern must not be match variable; found: ~A") (fullstrip1 (getop name)))))
      (setq *a* (genref))
      (setq plustimes (member name '(mplus mtimes) :test #'eq))
      (if (atom (if plustimes (errset (compilematch *a* pt))
 		   (errset (compileeach *a* (cdr pt)))))
-	 (merror "Match processing aborted~%"))
+	 (merror (intl:gettext "tellsimpafter: failed to compile match for pattern ~M") (cdr pt)))
      (setq oldstuff (get name 'operators))
      (setq rulenum (mget name 'rulenum))
      (if (null rulenum) (setq rulenum 1))
@@ -480,7 +486,7 @@
        '(x ans a3)
        (if oldstuff
          (list 'setq 'x (list oldstuff 'x 'ans 'a3))
-         '(declare (ignore a3)))
+         (list 'setq 'x (list 'simpargs1 'x 'ans 'a3)))
        (list
 	'cond
 	'(*afterflag x)
@@ -534,12 +540,12 @@
      (if (not (= (length l) 3)) (wna-err '$defrule))
      (setq name (car l))
      (if (or (not (symbolp name)) (mopp name) (member name '($all $%) :test #'eq))
-	 (merror "Improper rule name:~%~M" name))
+	 (merror (intl:gettext "defrule: rule name must be a symbol, and not an operator or 'all' or '%'; found: ~M") name))
      (setq pt (copy-tree (setq lhs* (simplify (cadr l)))))
      (setq rhs (copy-tree (setq rhs* (simplify (caddr l)))))
      (setq *a* (genref))
      (cond ((atom (errset (compilematch *a* pt)))
-	    (merror "Match processing aborted~%"))
+	    (merror (intl:gettext "defrule: failed to compile match for pattern ~M") pt))
 	   (t (meta-fset name
 			 (list 'lambda
 			       (list *a*)
